from setuptools import setup

setup(name='empirical_cdf',
    version='0.0.4',
    description='A Distribution Function Associated With The Empirical Measure Of A Sample.',
    url = 'https://github.com/Hotlynn2',
    author='Mr. Franklin Adjei',
    author_email='laizer421@gmail.com',
    license='MIT',
    packages=['empirical_cdf'],
    install_requires=['numpy', 'matplotlib'],
    include_package_data=True
)
 